pub struct NorthConfigOptions {
pub sources: Vec<ConfigSource>,
}Expand description
NorthConfigOptions
Represents the available options for initializing a NorthConfig.
Fields
sources: A list of available configuration sources from the environment.- Type:
Vec<ConfigSource> - Description: The potential sources of configuration data from the environment.
- Default: An empty vector (
Vec::new())
- Type:
Fields
sources: Vec<ConfigSource>a list of available env sources
Implementations
Sourceimpl NorthConfigOptions
impl NorthConfigOptions
pub fn new(sources: Vec<ConfigSource>) -> NorthConfigOptions