CustomConfigSource

Trait CustomConfigSource 

pub trait CustomConfigSource:
    CustomConfigSourceClone
    + Send
    + Sync {
    // Required method
    fn get_config_value(&self) -> Result<Value, Error>;
}
Allows for providing a custom configuration source.

This trait can be implemented to define a custom configuration source. The trait extends the CustomConfigSourceClone trait and requires the Self type to be cloneable and support sending between threads (Send) and sharing between threads (Sync).

Required Methods

fn get_config_value(&self) -> Result<Value, Error>

This is the only implementable member. Here you can return a serde value